Class: Google::Cloud::StorageBatchOperations::V1::BucketList
- Inherits:
-
Object
- Object
- Google::Cloud::StorageBatchOperations::V1::BucketList
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations_types.rb
Overview
Describes list of buckets and their objects to be transformed.
Defined Under Namespace
Classes: Bucket
Instance Attribute Summary collapse
Instance Attribute Details
#buckets ⇒ ::Array<::Google::Cloud::StorageBatchOperations::V1::BucketList::Bucket>
Returns Required. List of buckets and their objects to be transformed. Currently, only one bucket configuration is supported. If multiple buckets are specified, an error will be returned.
218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations_types.rb', line 218 class BucketList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes configuration of a single bucket and its objects to be # transformed. # @!attribute [rw] bucket # @return [::String] # Required. Bucket name for the objects to be transformed. # @!attribute [rw] prefix_list # @return [::Google::Cloud::StorageBatchOperations::V1::PrefixList] # Specifies objects matching a prefix set. # # Note: The following fields are mutually exclusive: `prefix_list`, `manifest`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] manifest # @return [::Google::Cloud::StorageBatchOperations::V1::Manifest] # Specifies objects in a manifest file. # # Note: The following fields are mutually exclusive: `manifest`, `prefix_list`. If a field in that set is populated, all other fields in the set will automatically be cleared. class Bucket include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |