Class: Google::Cloud::StorageBatchOperations::V1::BucketOperation

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations_types.rb

Overview

BucketOperation represents a bucket-level breakdown of a Job.

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#bucket_name::String

Returns The bucket name of the objects to be transformed in the BucketOperation.

Returns:

  • (::String)

    The bucket name of the objects to be transformed in the BucketOperation.



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations_types.rb', line 186

class BucketOperation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes state of the BucketOperation.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # Created but not yet started.
    QUEUED = 1

    # In progress.
    RUNNING = 2

    # Completed successfully.
    SUCCEEDED = 3

    # Cancelled by the user.
    CANCELED = 4

    # Terminated due to an unrecoverable failure.
    FAILED = 5
  end
end

#complete_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time that the BucketOperation was completed.

Returns:



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations_types.rb', line 186

class BucketOperation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes state of the BucketOperation.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # Created but not yet started.
    QUEUED = 1

    # In progress.
    RUNNING = 2

    # Completed successfully.
    SUCCEEDED = 3

    # Cancelled by the user.
    CANCELED = 4

    # Terminated due to an unrecoverable failure.
    FAILED = 5
  end
end

#counters::Google::Cloud::StorageBatchOperations::V1::Counters (readonly)

Returns Output only. Information about the progress of the bucket operation.

Returns:



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations_types.rb', line 186

class BucketOperation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes state of the BucketOperation.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # Created but not yet started.
    QUEUED = 1

    # In progress.
    RUNNING = 2

    # Completed successfully.
    SUCCEEDED = 3

    # Cancelled by the user.
    CANCELED = 4

    # Terminated due to an unrecoverable failure.
    FAILED = 5
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time that the BucketOperation was created.

Returns:



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations_types.rb', line 186

class BucketOperation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes state of the BucketOperation.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # Created but not yet started.
    QUEUED = 1

    # In progress.
    RUNNING = 2

    # Completed successfully.
    SUCCEEDED = 3

    # Cancelled by the user.
    CANCELED = 4

    # Terminated due to an unrecoverable failure.
    FAILED = 5
  end
end

#delete_object::Google::Cloud::StorageBatchOperations::V1::DeleteObject

Returns Delete objects.

Note: The following fields are mutually exclusive: delete_object, put_object_hold, put_metadata, rewrite_object, update_object_custom_context. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::StorageBatchOperations::V1::DeleteObject)

    Delete objects.

    Note: The following fields are mutually exclusive: delete_object, put_object_hold, put_metadata, rewrite_object, update_object_custom_context. If a field in that set is populated, all other fields in the set will automatically be cleared.



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations_types.rb', line 186

class BucketOperation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes state of the BucketOperation.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # Created but not yet started.
    QUEUED = 1

    # In progress.
    RUNNING = 2

    # Completed successfully.
    SUCCEEDED = 3

    # Cancelled by the user.
    CANCELED = 4

    # Terminated due to an unrecoverable failure.
    FAILED = 5
  end
end

#error_summaries::Array<::Google::Cloud::StorageBatchOperations::V1::ErrorSummary> (readonly)

Returns Output only. Summarizes errors encountered with sample error log entries.

Returns:



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations_types.rb', line 186

class BucketOperation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes state of the BucketOperation.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # Created but not yet started.
    QUEUED = 1

    # In progress.
    RUNNING = 2

    # Completed successfully.
    SUCCEEDED = 3

    # Cancelled by the user.
    CANCELED = 4

    # Terminated due to an unrecoverable failure.
    FAILED = 5
  end
end

#manifest::Google::Cloud::StorageBatchOperations::V1::Manifest

Returns Specifies objects in a manifest file.

Note: The following fields are mutually exclusive: manifest, prefix_list. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::StorageBatchOperations::V1::Manifest)

    Specifies objects in a manifest file.

    Note: The following fields are mutually exclusive: manifest, prefix_list. If a field in that set is populated, all other fields in the set will automatically be cleared.



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations_types.rb', line 186

class BucketOperation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes state of the BucketOperation.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # Created but not yet started.
    QUEUED = 1

    # In progress.
    RUNNING = 2

    # Completed successfully.
    SUCCEEDED = 3

    # Cancelled by the user.
    CANCELED = 4

    # Terminated due to an unrecoverable failure.
    FAILED = 5
  end
end

#name::String

Returns Identifier. The resource name of the BucketOperation. This is defined by the service. Format: projects/{project}/locations/global/jobs/{job_id}/bucketOperations/{bucket_operation}.

Returns:

  • (::String)

    Identifier. The resource name of the BucketOperation. This is defined by the service. Format: projects/{project}/locations/global/jobs/{job_id}/bucketOperations/{bucket_operation}.



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations_types.rb', line 186

class BucketOperation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes state of the BucketOperation.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # Created but not yet started.
    QUEUED = 1

    # In progress.
    RUNNING = 2

    # Completed successfully.
    SUCCEEDED = 3

    # Cancelled by the user.
    CANCELED = 4

    # Terminated due to an unrecoverable failure.
    FAILED = 5
  end
end

#prefix_list::Google::Cloud::StorageBatchOperations::V1::PrefixList

Returns Specifies objects matching a prefix set.

Note: The following fields are mutually exclusive: prefix_list, manifest. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations_types.rb', line 186

class BucketOperation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes state of the BucketOperation.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # Created but not yet started.
    QUEUED = 1

    # In progress.
    RUNNING = 2

    # Completed successfully.
    SUCCEEDED = 3

    # Cancelled by the user.
    CANCELED = 4

    # Terminated due to an unrecoverable failure.
    FAILED = 5
  end
end

#put_metadata::Google::Cloud::StorageBatchOperations::V1::PutMetadata

Returns Updates object metadata. Allows updating fixed-key and custom metadata and fixed-key metadata i.e. Cache-Control, Content-Disposition, Content-Encoding, Content-Language, Content-Type, Custom-Time.

Note: The following fields are mutually exclusive: put_metadata, put_object_hold, delete_object, rewrite_object, update_object_custom_context. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::StorageBatchOperations::V1::PutMetadata)

    Updates object metadata. Allows updating fixed-key and custom metadata and fixed-key metadata i.e. Cache-Control, Content-Disposition, Content-Encoding, Content-Language, Content-Type, Custom-Time.

    Note: The following fields are mutually exclusive: put_metadata, put_object_hold, delete_object, rewrite_object, update_object_custom_context. If a field in that set is populated, all other fields in the set will automatically be cleared.



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations_types.rb', line 186

class BucketOperation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes state of the BucketOperation.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # Created but not yet started.
    QUEUED = 1

    # In progress.
    RUNNING = 2

    # Completed successfully.
    SUCCEEDED = 3

    # Cancelled by the user.
    CANCELED = 4

    # Terminated due to an unrecoverable failure.
    FAILED = 5
  end
end

#put_object_hold::Google::Cloud::StorageBatchOperations::V1::PutObjectHold

Returns Changes object hold status.

Note: The following fields are mutually exclusive: put_object_hold, delete_object, put_metadata, rewrite_object, update_object_custom_context. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::StorageBatchOperations::V1::PutObjectHold)

    Changes object hold status.

    Note: The following fields are mutually exclusive: put_object_hold, delete_object, put_metadata, rewrite_object, update_object_custom_context. If a field in that set is populated, all other fields in the set will automatically be cleared.



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations_types.rb', line 186

class BucketOperation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes state of the BucketOperation.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # Created but not yet started.
    QUEUED = 1

    # In progress.
    RUNNING = 2

    # Completed successfully.
    SUCCEEDED = 3

    # Cancelled by the user.
    CANCELED = 4

    # Terminated due to an unrecoverable failure.
    FAILED = 5
  end
end

#rewrite_object::Google::Cloud::StorageBatchOperations::V1::RewriteObject

Returns Rewrite the object and updates metadata like KMS key.

Note: The following fields are mutually exclusive: rewrite_object, put_object_hold, delete_object, put_metadata, update_object_custom_context. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::StorageBatchOperations::V1::RewriteObject)

    Rewrite the object and updates metadata like KMS key.

    Note: The following fields are mutually exclusive: rewrite_object, put_object_hold, delete_object, put_metadata, update_object_custom_context. If a field in that set is populated, all other fields in the set will automatically be cleared.



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations_types.rb', line 186

class BucketOperation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes state of the BucketOperation.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # Created but not yet started.
    QUEUED = 1

    # In progress.
    RUNNING = 2

    # Completed successfully.
    SUCCEEDED = 3

    # Cancelled by the user.
    CANCELED = 4

    # Terminated due to an unrecoverable failure.
    FAILED = 5
  end
end

#start_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time that the BucketOperation was started.

Returns:



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations_types.rb', line 186

class BucketOperation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes state of the BucketOperation.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # Created but not yet started.
    QUEUED = 1

    # In progress.
    RUNNING = 2

    # Completed successfully.
    SUCCEEDED = 3

    # Cancelled by the user.
    CANCELED = 4

    # Terminated due to an unrecoverable failure.
    FAILED = 5
  end
end

#state::Google::Cloud::StorageBatchOperations::V1::BucketOperation::State (readonly)

Returns Output only. State of the BucketOperation.

Returns:



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations_types.rb', line 186

class BucketOperation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes state of the BucketOperation.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # Created but not yet started.
    QUEUED = 1

    # In progress.
    RUNNING = 2

    # Completed successfully.
    SUCCEEDED = 3

    # Cancelled by the user.
    CANCELED = 4

    # Terminated due to an unrecoverable failure.
    FAILED = 5
  end
end

#update_object_custom_context::Google::Cloud::StorageBatchOperations::V1::UpdateObjectCustomContext

Returns Update object custom context.

Note: The following fields are mutually exclusive: update_object_custom_context, put_object_hold, delete_object, put_metadata, rewrite_object. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations_types.rb', line 186

class BucketOperation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes state of the BucketOperation.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # Created but not yet started.
    QUEUED = 1

    # In progress.
    RUNNING = 2

    # Completed successfully.
    SUCCEEDED = 3

    # Cancelled by the user.
    CANCELED = 4

    # Terminated due to an unrecoverable failure.
    FAILED = 5
  end
end