Class: Google::Cloud::StorageBatchOperations::V1::DeleteJobRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations.rb

Overview

Message for deleting a Job

Instance Attribute Summary collapse

Instance Attribute Details

#force::Boolean

Returns Optional. If set to true, any child bucket operations of the job will also be deleted. Highly recommended to be set to true by all clients. Users cannot mutate bucket operations directly, so only the jobs.delete permission is required to delete a job (and its child bucket operations).

Returns:

  • (::Boolean)

    Optional. If set to true, any child bucket operations of the job will also be deleted. Highly recommended to be set to true by all clients. Users cannot mutate bucket operations directly, so only the jobs.delete permission is required to delete a job (and its child bucket operations).



130
131
132
133
# File 'proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations.rb', line 130

class DeleteJobRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. The name of the job to delete. Format: projects/{project_id}/locations/global/jobs/{job_id} .

Returns:

  • (::String)

    Required. The name of the job to delete. Format: projects/{project_id}/locations/global/jobs/{job_id} .



130
131
132
133
# File 'proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations.rb', line 130

class DeleteJobRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#request_id::String

Returns Optional. An optional request ID to identify requests. Specify a unique request ID in case you need to retry your request. Requests with same request_id will be ignored for at least 60 minutes since the first request. The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).

Returns:

  • (::String)

    Optional. An optional request ID to identify requests. Specify a unique request ID in case you need to retry your request. Requests with same request_id will be ignored for at least 60 minutes since the first request. The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).



130
131
132
133
# File 'proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations.rb', line 130

class DeleteJobRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end