Class: Google::Cloud::StorageBatchOperations::V1::UpdateObjectCustomContext

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations_types.rb

Overview

Describes options to update object custom contexts.

Instance Attribute Summary collapse

Instance Attribute Details

#clear_all::Boolean

Returns If set, must be set to true and all existing object custom contexts will be deleted.

Note: The following fields are mutually exclusive: clear_all, custom_context_updates. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Boolean)

    If set, must be set to true and all existing object custom contexts will be deleted.

    Note: The following fields are mutually exclusive: clear_all, custom_context_updates. If a field in that set is populated, all other fields in the set will automatically be cleared.



473
474
475
476
# File 'proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations_types.rb', line 473

class UpdateObjectCustomContext
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#custom_context_updates::Google::Cloud::StorageBatchOperations::V1::CustomContextUpdates

Returns A collection of updates to apply to specific custom contexts. Use this to add, update or delete individual contexts by key.

Note: The following fields are mutually exclusive: custom_context_updates, clear_all. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::StorageBatchOperations::V1::CustomContextUpdates)

    A collection of updates to apply to specific custom contexts. Use this to add, update or delete individual contexts by key.

    Note: The following fields are mutually exclusive: custom_context_updates, clear_all. If a field in that set is populated, all other fields in the set will automatically be cleared.



473
474
475
476
# File 'proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations_types.rb', line 473

class UpdateObjectCustomContext
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end