Class: Google::Cloud::StorageBatchOperations::V1::Counters
- Inherits:
-
Object
- Object
- Google::Cloud::StorageBatchOperations::V1::Counters
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations_types.rb
Overview
Describes details about the progress of the job.
Instance Attribute Summary collapse
-
#failed_object_count ⇒ ::Integer
readonly
Output only.
-
#object_custom_contexts_created ⇒ ::Integer
readonly
Output only.
-
#object_custom_contexts_deleted ⇒ ::Integer
readonly
Output only.
-
#object_custom_contexts_updated ⇒ ::Integer
readonly
Output only.
-
#succeeded_object_count ⇒ ::Integer
readonly
Output only.
-
#total_bytes_found ⇒ ::Integer
readonly
Output only.
-
#total_object_count ⇒ ::Integer
readonly
Output only.
Instance Attribute Details
#failed_object_count ⇒ ::Integer (readonly)
Returns Output only. The number of objects that failed due to user errors or service errors.
536 537 538 539 |
# File 'proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations_types.rb', line 536 class Counters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#object_custom_contexts_created ⇒ ::Integer (readonly)
Returns Output only. Number of object custom contexts created. This field is only populated for jobs with the UpdateObjectCustomContext transformation.
536 537 538 539 |
# File 'proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations_types.rb', line 536 class Counters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#object_custom_contexts_deleted ⇒ ::Integer (readonly)
Returns Output only. Number of object custom contexts deleted. This field is only populated for jobs with the UpdateObjectCustomContext transformation.
536 537 538 539 |
# File 'proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations_types.rb', line 536 class Counters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#object_custom_contexts_updated ⇒ ::Integer (readonly)
Returns Output only. Number of object custom contexts updated. This counter tracks custom contexts where the key already existed, but the payload was modified. This field is only populated for jobs with the UpdateObjectCustomContext transformation.
536 537 538 539 |
# File 'proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations_types.rb', line 536 class Counters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#succeeded_object_count ⇒ ::Integer (readonly)
Returns Output only. Number of objects completed.
536 537 538 539 |
# File 'proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations_types.rb', line 536 class Counters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#total_bytes_found ⇒ ::Integer (readonly)
Returns Output only. Number of bytes found from source. This field is only populated for jobs with a prefix list object configuration.
536 537 538 539 |
# File 'proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations_types.rb', line 536 class Counters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#total_object_count ⇒ ::Integer (readonly)
Returns Output only. Number of objects listed.
536 537 538 539 |
# File 'proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations_types.rb', line 536 class Counters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |