Class: Google::Cloud::StorageBatchOperations::V1::CustomContextUpdates
- Inherits:
-
Object
- Object
- Google::Cloud::StorageBatchOperations::V1::CustomContextUpdates
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations_types.rb
Overview
Describes a collection of updates to apply to custom contexts identified by key.
Defined Under Namespace
Classes: UpdatesEntry
Instance Attribute Summary collapse
-
#keys_to_clear ⇒ ::Array<::String>
Optional.
-
#updates ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::StorageBatchOperations::V1::ObjectCustomContextPayload}
Optional.
Instance Attribute Details
#keys_to_clear ⇒ ::Array<::String>
Returns Optional. Custom contexts to clear by key.
A key cannot be present in both updates and keys_to_clear.
446 447 448 449 450 451 452 453 454 455 456 457 458 |
# File 'proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations_types.rb', line 446 class CustomContextUpdates include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::StorageBatchOperations::V1::ObjectCustomContextPayload] class UpdatesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#updates ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::StorageBatchOperations::V1::ObjectCustomContextPayload}
Returns Optional. Insert or update the existing custom contexts.
446 447 448 449 450 451 452 453 454 455 456 457 458 |
# File 'proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations_types.rb', line 446 class CustomContextUpdates include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::StorageBatchOperations::V1::ObjectCustomContextPayload] class UpdatesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |