Class: Google::Cloud::StorageBatchOperations::V1::ObjectCustomContextPayload
- Inherits:
-
Object
- Object
- Google::Cloud::StorageBatchOperations::V1::ObjectCustomContextPayload
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations_types.rb
Overview
Describes the payload of a user defined object custom context.
Instance Attribute Summary collapse
-
#value ⇒ ::String
The value of the object custom context.
Instance Attribute Details
#value ⇒ ::String
Returns The value of the object custom context.
If set, value must NOT be an empty string since it is a required field in
custom context. If unset, value will be ignored and no changes will be
made to the value field of the custom context payload.
432 433 434 435 |
# File 'proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations_types.rb', line 432 class ObjectCustomContextPayload include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |