Class: Google::Cloud::StorageBatchOperations::V1::PutObjectHold
- Inherits:
-
Object
- Object
- Google::Cloud::StorageBatchOperations::V1::PutObjectHold
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations_types.rb
Overview
Describes options to update object hold.
Defined Under Namespace
Modules: HoldStatus
Instance Attribute Summary collapse
-
#event_based_hold ⇒ ::Google::Cloud::StorageBatchOperations::V1::PutObjectHold::HoldStatus
Required.
-
#temporary_hold ⇒ ::Google::Cloud::StorageBatchOperations::V1::PutObjectHold::HoldStatus
Required.
Instance Attribute Details
#event_based_hold ⇒ ::Google::Cloud::StorageBatchOperations::V1::PutObjectHold::HoldStatus
Returns Required. Updates object event based holds state. When object event based hold is set, object cannot be deleted or replaced. Resets object's time in the bucket for the purposes of the retention period.
284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations_types.rb', line 284 class PutObjectHold include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes the status of the hold. module HoldStatus # Default value, Object hold status will not be changed. HOLD_STATUS_UNSPECIFIED = 0 # Places the hold. SET = 1 # Releases the hold. UNSET = 2 end end |
#temporary_hold ⇒ ::Google::Cloud::StorageBatchOperations::V1::PutObjectHold::HoldStatus
Returns Required. Updates object temporary holds state. When object temporary hold is set, object cannot be deleted or replaced.
284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations_types.rb', line 284 class PutObjectHold include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes the status of the hold. module HoldStatus # Default value, Object hold status will not be changed. HOLD_STATUS_UNSPECIFIED = 0 # Places the hold. SET = 1 # Releases the hold. UNSET = 2 end end |