Class: Google::Cloud::StorageBatchOperations::V1::UpdateObjectCustomContext
- Inherits:
-
Object
- Object
- Google::Cloud::StorageBatchOperations::V1::UpdateObjectCustomContext
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations_types.rb
Overview
Describes options to update object custom contexts.
Instance Attribute Summary collapse
-
#clear_all ⇒ ::Boolean
If set, must be set to true and all existing object custom contexts will be deleted.
-
#custom_context_updates ⇒ ::Google::Cloud::StorageBatchOperations::V1::CustomContextUpdates
A collection of updates to apply to specific custom contexts.
Instance Attribute Details
#clear_all ⇒ ::Boolean
473 474 475 476 |
# File 'proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations_types.rb', line 473 class UpdateObjectCustomContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#custom_context_updates ⇒ ::Google::Cloud::StorageBatchOperations::V1::CustomContextUpdates
473 474 475 476 |
# File 'proto_docs/google/cloud/storagebatchoperations/v1/storage_batch_operations_types.rb', line 473 class UpdateObjectCustomContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |